aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/adm
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/adm')
-rw-r--r--phpBB/adm/index.php6
-rw-r--r--phpBB/adm/style/acp_main.html4
-rw-r--r--phpBB/adm/style/acp_permissions.html23
-rw-r--r--phpBB/adm/style/confirm_body.html2
-rw-r--r--phpBB/adm/style/confirm_body_prune.html30
-rw-r--r--phpBB/adm/style/overall_header.html23
6 files changed, 61 insertions, 27 deletions
diff --git a/phpBB/adm/style/acp_main.html b/phpBB/adm/style/acp_main.html
index 7d29a43070..6b96a3e418 100644
--- a/phpBB/adm/style/acp_main.html
+++ b/phpBB/adm/style/acp_main.html
@@ -94,14 +94,14 @@
<form id="action_online_form" method="post" action="{U_ACTION}">
<dl>
- <dt><label for="action_online">{L_RESET_ONLINE}</label></dt>
+ <dt><label for="action_online">{L_RESET_ONLINE}</label><br /><span>&nbsp;</span></dt>
<dd><input type="hidden" name="action" value="online" /><input class="button2" type="submit" id="action_online" name="action_online" value="{L_RUN}" /></dd>
</dl>
</form>
<form id="action_date_form" method="post" action="{U_ACTION}">
<dl>
- <dt><label for="action_date">{L_RESET_DATE}</label></dt>
+ <dt><label for="action_date">{L_RESET_DATE}</label><br /><span>&nbsp;</span></dt>
<dd><input type="hidden" name="action" value="date" /><input class="button2" type="submit" id="action_date" name="action_date" value="{L_RUN}" /></dd>
</dl>
</form>
diff --git a/phpBB/adm/style/acp_permissions.html b/phpBB/adm/style/acp_permissions.html
index 22bc012377..7d752c250c 100644
--- a/phpBB/adm/style/acp_permissions.html
+++ b/phpBB/adm/style/acp_permissions.html
@@ -17,7 +17,7 @@
<p>{L_EXPLAIN}</p>
<!-- IF S_FORUM_NAMES -->
- <p><b>{L_FORUMS}:</b> {FORUM_NAMES}</p>
+ <p><strong>{L_FORUMS}:</strong> {FORUM_NAMES}</p>
<!-- ENDIF -->
<!-- IF S_SELECT_FORUM -->
@@ -32,11 +32,12 @@
<dd><select id="forum" name="forum_id[]"<!-- IF S_FORUM_MULTIPLE --> multiple="multiple"<!-- ENDIF --> size="10">{S_FORUM_OPTIONS}</select></dd>
<!-- IF S_FORUM_ALL --><dd><input type="checkbox" class="radio" name="all_forums" value="1" />&nbsp; {L_ALL_FORUMS}</dd><!-- ENDIF -->
</dl>
- </fieldset>
- <fieldset class="quick">
+ <p class="quick">
{S_HIDDEN_FIELDS}
<input type="submit" name="submit" value="{L_SUBMIT}" class="button1" />
+ </p>
+
</fieldset>
</form>
@@ -52,11 +53,12 @@
<dt><label for="sforum">{L_LOOK_UP_FORUM}:</label></dt>
<dd><select id="sforum" name="subforum_id">{S_SUBFORUM_OPTIONS}</select></dd>
</dl>
- </fieldset>
- <fieldset class="quick">
+ <p class="quick">
{S_HIDDEN_FIELDS}
<input type="submit" name="submit" value="{L_SUBMIT}" class="button1" />
+ </p>
+
</fieldset>
</form>
@@ -75,11 +77,11 @@
<dd>[ <a href="{U_FIND_USERNAME}" onclick="find_username(); return false;">{L_FIND_USERNAME}</a> ]</dd>
<dd class="full" style="text-align: left;"><input type="checkbox" class="radio" id="anonymous" name="user_id[]" value="{ANONYMOUS_USER_ID}" /> &nbsp;{L_SELECT_ANONYMOUS}</dd>
</dl>
- </fieldset>
- <fieldset class="quick">
+ <p class="quick">
{S_HIDDEN_FIELDS}
<input type="submit" name="submit" value="{L_SUBMIT}" class="button1" />
+ </p>
</fieldset>
</form>
@@ -94,11 +96,12 @@
<dt><label for="group">{L_LOOK_UP_GROUP}:</label></dt>
<dd><select name="group_id[]" id="group">{S_GROUP_OPTIONS}</select></dd>
</dl>
- </fieldset>
- <fieldset class="quick">
+ <p class="quick">
{S_HIDDEN_FIELDS}
<input type="submit" name="submit" value="{L_SUBMIT}" class="button1" />
+ </p>
+
</fieldset>
</form>
@@ -106,7 +109,7 @@
<!-- ELSEIF S_SELECT_USERGROUP -->
<div style="float: left; width: 48%;">
-
+
<!-- IF S_CAN_SELECT_USER -->
<h1>{L_USERS}</h1>
diff --git a/phpBB/adm/style/confirm_body.html b/phpBB/adm/style/confirm_body.html
index 6c1894e748..2fbb1a60d7 100644
--- a/phpBB/adm/style/confirm_body.html
+++ b/phpBB/adm/style/confirm_body.html
@@ -3,7 +3,7 @@
<form id="confirm" method="post" action="{S_CONFIRM_ACTION}">
<fieldset>
- <h2>{MESSAGE_TITLE}</h2>
+ <h1>{MESSAGE_TITLE}</h1>
<p>{MESSAGE_TEXT}</p>
{S_HIDDEN_FIELDS}
diff --git a/phpBB/adm/style/confirm_body_prune.html b/phpBB/adm/style/confirm_body_prune.html
new file mode 100644
index 0000000000..9481386231
--- /dev/null
+++ b/phpBB/adm/style/confirm_body_prune.html
@@ -0,0 +1,30 @@
+<!-- INCLUDE overall_header.html -->
+
+<form id="confirm" method="post" action="{S_CONFIRM_ACTION}">
+
+<fieldset>
+ <h1>{MESSAGE_TITLE}</h1>
+ <p>{MESSAGE_TEXT}</p>
+
+ {S_HIDDEN_FIELDS}
+
+ <div style="text-align: center;">
+ <input type="submit" name="confirm" value="{L_YES}" class="button2" />&nbsp;
+ <input type="submit" name="cancel" value="{L_NO}" class="button2" />
+ </div>
+
+ <h2>{L_PRUNE_USERS_LIST}</h2>
+ <!-- IF S_DEACTIVATE --><p>{L_PRUNE_USERS_LIST_DEACTIVATE}</p><!-- ELSE --><p>{L_PRUNE_USERS_LIST_DELETE}</p><!-- ENDIF -->
+
+ <br />
+ <!-- BEGIN users -->
+ &raquo; <a href="{users.U_PROFILE}">{users.USERNAME}</a><!-- IF users.U_USER_ADMIN --> [<a href="{users.U_USER_ADMIN}">{L_USER_ADMIN}</a>]<!-- ENDIF --><br />
+ <!-- END users -->
+
+ <br /><br />
+
+</fieldset>
+
+</form>
+
+<!-- INCLUDE overall_footer.html -->
diff --git a/phpBB/adm/style/overall_header.html b/phpBB/adm/style/overall_header.html
index 9024c08577..d75d89ab13 100644
--- a/phpBB/adm/style/overall_header.html
+++ b/phpBB/adm/style/overall_header.html
@@ -120,32 +120,33 @@ function switch_menu()
var menu = document.getElementById('menu');
var main = document.getElementById('main');
var toggle = document.getElementById('toggle');
- var handle = document.getElementById('toggle-handle');
+ var handle = document.getElementById('toggle-handle');
- switch(menu_state)
- {
- //hidden
+ switch (menu_state)
+ {
+ // hide
case 'shown':
- main.style.width = 'auto';
- menu.style.display = 'none';
+ main.style.width = '93%';
menu_state = 'hidden';
+ menu.style.display = 'none';
toggle.style.left = '0';
toggle.style.width = '20px';
handle.style.backgroundImage = 'url(images/toggle.gif)';
handle.style.backgroundPosition = '100% 50%';
handle.style.backgroundRepeat = 'no-repeat';
- break;
- //shown
+ break;
+
+ // show
case 'hidden':
main.style.width = '76%';
- menu.style.display = 'block';
menu_state = 'shown';
+ menu.style.display = 'block';
toggle.style.left = '15%';
toggle.style.width = '5%';
handle.style.backgroundImage = 'url(images/toggle.gif)';
handle.style.backgroundPosition = '0% 50%';
- handle.style.backgroundRepeat = 'no-repeat';
- break;
+ handle.style.backgroundRepeat = 'no-repeat';
+ break;
}
}
diff --git a/phpBB/adm/index.php b/phpBB/adm/index.php
index d0d91adbbb..84fc31c290 100644
--- a/phpBB/adm/index.php
+++ b/phpBB/adm/index.php
@@ -483,12 +483,12 @@ function validate_config_vars($config_vars, &$cfg_array, &$error)
$error[] = sprintf($user->lang['DIRECTORY_NOT_DIR'], $cfg_array[$config_name]);
}
// Check if the path is writeable
if ($config_definition['validate'] == 'wpath' || $config_definition['validate'] == 'rwpath')
{
- if (file_exists($phpbb_root_path . $cfg_array[$config_name]) && !is_writeable($phpbb_root_path . $cfg_array[$config_name]))
+ if (file_exists($phpbb_root_path . $cfg_array[$config_name]) && !@is_writable($phpbb_root_path . $cfg_array[$config_name]))
{
- $error[] = sprintf($user->lang['DIRECTORY_NOT_WRITEABLE'], $cfg_array[$config_name]);
+ $error[] = sprintf($user->lang['DIRECTORY_NOT_WRITABLE'], $cfg_array[$config_name]);
}
}
@@ -483,12 +483,12 @@ function validate_config_vars($config_vars, &$cfg_array, &$error)
$error[] = sprintf($user->lang['DIRECTORY_NOT_DIR'], $cfg_array[$config_name]);
}
- // Check if the path is writeable
+ // Check if the path is writable
if ($config_definition['validate'] == 'wpath' || $config_definition['validate'] == 'rwpath')
{